<?php
/**
 * classes/ibit_Action_Handler_Teacher.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version 1.5
 */

/**
 * Diese Klasse enthlt alle Funktionen, die ein Dozent ausfhren kann.
 *
 * @author     Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @package    IBIT_Evaluation
 * @subpackage Action_Handler
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.5
 */
class ibit_Action_Handler_Teacher extends ibit_Action_Handler
{
	/**
	 * Id des Dozenten
	 * @var string $user_id
	 */
	var $user_id;

	var $preview_link;

	/**
	 * Konstruktor der Klasse.
	 * Initialisiert die Klasse, indem der Konstruktor der Elternklasse mit dem bergebenen aufrufenden Objekt
	 * und den Standardwerten fr Sektion und Funktion aufgerufen wird.
	 *
	 * @param object $parent Referenz auf das aufrufende Objekt
	 * @param string $user_id Id des Dozenten
	 */
	function ibit_Action_Handler_Teacher($parent, $user_id)
	{
		$this->user_id = $user_id;
		parent::ibit_Action_Handler($parent, 'expired', 'index');
	}

	function evaluation_preview()
	{
		$evaluation_id = $_GET['evaluation_id'];

		if (empty($evaluation_id) or !is_numeric($evaluation_id))
		{
			echo Messagebox::error('Evaluation kann nicht angezeigt werden' );
			return;
		}
		$evaluation = new ibit_Evaluation($evaluation_id);
		$eval_template = new ibit_EvaluationTemplate($evaluation->getTemplateId());

		$template = $this->parent->getTemplate('common_display_template.php');
		$template->set_attribute('template', $eval_template->flattenToArray());
		$template->set_attribute('link_back', PluginEngine::getLink($this->parent, array('section'=>$_REQUEST['fallback'])));
		$template->set_attribute('hide', true);
		echo $template->render();
	}

	/**
	 * Zeigt die Hauptseite der abgeschlossenen Evaluationen an.
	 * @uses ibit_Evaluation::getEvaluationDataByUserId()
	 */
	function expired_index()
	{
		$evaluations = ibit_Evaluation::getEvaluationDataByUserId( $this->user_id, true );
		$template = $this->parent->getTemplate('dozent_display_expired.php');
		$template->set_attribute('evaluations', $evaluations['expired']);
		$template->set_attribute('link_activate', $this->section_link.'&function=activate');
		$template->set_attribute('link_comment', $this->section_link.'&function=comment');
		$template->set_attribute('link_summary', $this->section_link.'&function=summary');
		$template->set_attribute('link_preview', PluginEngine::getLink($this->parent, array('section'=>'evaluation', 'function'=>'preview', 'fallback'=>'expired')));
		$template->set_attribute('min_users', ibit_EvaluationConfig::GetConfig('evaluation', 'min_users'));
		echo $template->render();
	}

	/**
	 * Zeigt die Auswertung einer Evaluation an.
	 * @uses ibit_Action_Summary
	 */
	function expired_summary()
	{
		$evaluation_id = trim($_REQUEST['evaluation_id']);
		$summary = new ibit_Action_Summary( $this->parent , $evaluation_id );
		$summary->show();
	}

	/**
	 * Schaltet eine Evaluation frei oder sperrt sie.
	 * @uses ibit_Evaluation
	 */
	function expired_activate()
	{
		$evaluation_id = $_REQUEST['evaluation_id'];
		$visible_status = ( $_REQUEST['visible'] == 1 );

		$evaluation = new ibit_Evaluation( $evaluation_id );
		$evaluation->setVisible( $visible_status, $_SESSION['auth']->auth['uid']);
		$evaluation->save();

        //cache leeren
        StudipCacheFactory::getCache()->expire(md5('auswertung'.$evaluation_id).'/overview');

		echo Messagebox::success('Ihre nderung wurde erfolgreich gespeichert.');

		$this->expired_index();
	}

	/**
	 * Speichert einen Kommentar des Dozenten bzw. zeigt das Formular zum Eingeben an.
	 * @uses ibit_Evaluation
	 */
	function expired_comment()
	{
		$evaluation_id = $_REQUEST['evaluation_id'];

		if( !empty( $_REQUEST['action'] ) and $_REQUEST['action'] == "submit")
		{
			#speichern
			$evaluation = new ibit_Evaluation( $evaluation_id );
			$evaluation->setComment( $_REQUEST['comment'] );
			$evaluation->save();

            //cache leeren
            StudipCacheFactory::getCache()->expire(md5('auswertung'.$evaluation_id).'/overview');

			echo Messagebox::success('Ihr Kommentar wurde erfolgreich gespeichert.');

			$this->expired_index();
			return;
		}

		#eingabe feld anzeigen
		$evaluation = new ibit_Evaluation( $evaluation_id );
		$comment = $evaluation->getComment();

		$template = $this->parent->getTemplate('dozent_comment');
		$template->set_attribute('link_comment', $this->section_link.'&function=comment');
		$template->set_attribute('evaluation_id', $evaluation_id);
		$template->set_attribute('comment', $comment);
		$template->set_attribute('link_back', $this->section_link);
		echo $template->render();
	}

	/**
	 * Zeigt die Hauptseite der laufenden Evaluationen an.
	 * @uses ibit_Evaluation::getEvaluationDataByUserId()
	 */
	function running_index()
	{
		$evaluations = ibit_Evaluation::getEvaluationDataByUserId($this->user_id, true);
		$template = $this->parent->getTemplate('dozent_display_running.php');
		$template->set_attribute('evaluations', $evaluations['running']);
		$template->set_attribute('link_participate', $this->section_link.'&function=participate');
		$template->set_attribute('link_preview', PluginEngine::getLink($this->parent, array('section'=>'evaluation', 'function'=>'preview', 'fallback'=>'running')));
		echo $template->render();
	}

	/**
	 * Zeigt die Hauptseite der zuknftigen Evaluationen an
	 * @uses ibit_Evaluation::getEvaluationDataByUserId()
	 */
	function future_index()
	{
		$evaluations = ibit_Evaluation::getEvaluationDataByUserId($this->user_id, true);
		$template = $this->parent->getTemplate('dozent_display_future.php');
		$template->set_attribute('evaluations', $evaluations['future']);
		$template->set_attribute('link_preview', PluginEngine::getLink($this->parent, array('section'=>'evaluation', 'function'=>'preview', 'fallback'=>'future')));
		echo $template->render();
	}
}
?>