<?php
/**
 * classes/ibit_Action_Handler_User.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright IBIT 2006, 2007, 2008
 * @version 2.0.13
 */

/**
 * Diese Klasse enthlt alle Funktionen, die ein Student ausfhren kann.
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author     Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @package    IBIT_Evaluation
 * @subpackage Action_Handler
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    2.0.8
 */
class ibit_Action_Handler_User extends ibit_Action_Handler
{
	/**
	 * Id des Studenten
	 * @var string $user_id
	 */
	var $user_id;

	/**
	 * Konstruktor der Klasse.
	 * Initialisiert die Klasse, indem der Konstruktor der Elternklasse mit dem bergebenen aufrufenden Objekt
	 * und den Standardwerten fr Sektion und Funktion aufgerufen wird.
	 *
	 * @param object $parent Referenz auf das aufrufende Objekt
	 * @param string $user_id Id des Studenten
	 */
	function ibit_Action_Handler_User( $parent, $user_id )
	{
		$this->user_id = $user_id;
		parent::ibit_Action_Handler( $parent, 'running', 'index' );
	}

	/**
	 * Zeigt die Hauptseite der laufenden Evaluationen an.
	 * @uses ibit_Evaluation::getEvaluationDataByUserId()
	 */
	function running_index()
	{
		$evaluations = ibit_Evaluation::getEvaluationDataByUserId($this->user_id);

		$template = $this->parent->getTemplate('student_display_running.php');
		$template->set_attribute('evaluations', $evaluations['running']['not_participated']);
		$template->set_attribute('link_participate', $this->section_link.'&function=participate');
		echo $template->render();
	}

	/**
	 * Zeigt das Teilnahmeformular einer Evaluation an.
	 */
	function running_participate()
	{
		$evaluation_id = $_REQUEST['evaluation_id'];

		if ( !$evaluation = $this->running_checkAndLoadEvaluation( $evaluation_id ) )
		{
			return;
		}

		$evaluation->loadSeminar();

		$template = $this->parent->getTemplate('common_display_template.php');
		$template->set_attribute('seminar_name', $evaluation->seminar->getName());
		$template->set_attribute('template', $evaluation->template->flattenToArray());
		$template->set_attribute('evaluation_id', $evaluation->getId());
		$template->set_attribute('link_back', $this->section_link);
		$template->set_attribute('link_confirm', $this->section_link.'&function=confirm');
		$template->set_attribute('participate', true);
		echo $template->render();
	}

	/**
	 * Zeigt eine Besttigungsseite fr die aktuelle Teilnahme einer Evaluation an.
	 */
	function running_confirm()
	{
		function stripslashes_deep( $value )
		{
			return is_array( $value ) ? array_map( 'stripslashes_deep', $value ) : stripslashes( $value );
		}
		if ( get_magic_quotes_gpc() or get_magic_quotes_runtime() )
		{
			$_POST = stripslashes_deep( $_POST );
		}

		$evaluation_id = $_REQUEST['evaluation_id'];

		if ( !$evaluation = $this->running_checkAndLoadEvaluation( $evaluation_id ) )
		{
			return;
		}

		$evaluation->loadSeminar();

		$template = $this->parent->getTemplate('common_display_template_confirm.php');
		$template->set_attribute('seminar_name', $evaluation->seminar->getName());
		$template->set_attribute('template', $evaluation->template->flattenToArray());
		$template->set_attribute('evaluation_id', $evaluation->getId());
		$template->set_attribute('link_participate', $this->section_link.'&function=participated');
		echo $template->render();
	}

	/**
	 * Verwaltet die Eingaben des Users und schliesst die Teilnahme an der Evaluation gegebenenfalls ab.
	 * @uses ibit_Action_EvaluationParticipate
	 */
	function running_participated()
	{
		//zurck zur Evaluation, also nciht abschicken
		if (!empty($_REQUEST['notconfirmed']) || !empty($_REQUEST['notconfirmed_x']))
		{
			$this->running_participate();
			return;
		}

		$evaluation_id = $_REQUEST['evaluation_id'];

		if ( !$evaluation = $this->running_checkAndLoadEvaluation( $evaluation_id ) )
		{
			return;
		}

		$answers = Array();
		foreach ( $_POST['answers'] as $key=>$value )
		{
			$parameters = explode( '.', $key );
			$group_id = array_shift( $parameters );
			$question_id = array_shift( $parameters );

			//freitext...
			if ( !empty( $parameters ) )
			{
				$value = array_shift( $parameters ).'|'.$value;
			}

			if ( $value == 'undefined' )
			{
				continue;
			}

			if ( !is_array( $value ) )
			{
				$value = Array( $value );
			}

			foreach ( $value as $item )
			{
			    $parameters = explode( '|', $item, 2 );
				$answer_id = array_shift( $parameters );
				$item = array_shift( $parameters );

    			if ( $item === '' )
				{
				    continue;
				}

				$answer = array();
				$answer['group_id'] = $group_id;
				$answer['question_id'] = $question_id;
				$answer['answer_id'] = $answer_id;
				$answer['value'] = $item;
				//TODO: geht nicht mehr, mysql_real_escape_string leifer false zurck...

				/*if ( get_magic_quotes_gpc() or get_magic_quotes_runtime() )
				{
				    echo "<br>vor mysql bla: ".$answer['value'];
				    $answer['value'] = mysql_real_escape_string($answer['value']);
				    echo "<br>nach mysql bla: ".$answer['value'];
				}*/

				array_push( $answers, $answer );
			}
		}

		if ( empty( $answers ) )
		{
			echo Messagebox::error('Ihre Teilnahme war nicht erfolgreich, da keine Antworten ausgewhlt wurden!<br/>Bitte fllen Sie die Evaluation aus oder brechen Sie die Teilnehme ber den entsprechenden Button ab');
			$this->participate();
			return;
		}

		$participation = new ibit_Action_EvaluationParticipate( $evaluation_id, $this->user_id );
		foreach ( $answers as $answer )
		{
			$participation->answer( $answer['group_id'], $answer['question_id'], $answer['answer_id'], $answer['value'] );
		}
		$participation->store();

		echo Messagebox::success('Ihre Antworten wurden gespeichert!<br/>Vielen Dank fr Ihre Teilnahme an der Evaluation');
		$this->running_index();
	}

	/**
	 * Prft, ob der User an der Evaluation teilnehmen darf und ob die Evaluation berhaupt valide ist.
	 * Gibt im Erfolgsfall das Evaluationsobjekt zurck.
	 *
	 * @param int $evaluation_id Id der Evaluation
	 * @return object|false false bei Fehler, ansonsten das Evaluations-Objekt
	 * @uses ibit_Evaluation
	 * @uses ibit_Evaluation::userParticipatedInEvaluation()
	 * @uses ibit_Evaluation::userValidForEvaluation()
	 */
	function running_checkAndLoadEvaluation( $evaluation_id )
	{
		$evaluation = new ibit_Evaluation( $evaluation_id );
		if ( $evaluation === false )
		{
			$error = 'Fehler beim Laden der Evaluation';
		}
		elseif ( ibit_Evaluation::userParticipatedInEvaluation( $this->user_id, $evaluation_id ) )
		{
			$error = 'Sie haben an der Evaluation bereits teilgenommen';
		}
		elseif ( !ibit_Evaluation::userValidForEvaluation( $this->user_id, $evaluation_id ) )
		{
			$error = 'Sie sind fr die Evaluation nicht zugelassen';
		}
		elseif ( $evaluation->getStartDate() > time() )
		{
			$error = 'Die Evaluation ist noch nicht gestartet';
		}
		elseif ( $evaluation->getStopDate() < time() )
		{
			$error = 'Die Evaluation ist bereits beendet';
		}

		if ( !empty( $error ) )
		{
			echo Messagebox::error($error);
			$this->running_index();
			return;
		}

		$evaluation->loadTemplate();
		return $evaluation;
	}

	/**
	 * Zeigt die Hauptseite der teilgenommenen Evaluationen an.
	 * @uses ibit_Evaluation::getEvaluationDataByUserId()
	 */
	function participated_index()
	{
		$evaluations = ibit_Evaluation::getEvaluationDataByUserId( $this->user_id );

		$template = $this->parent->getTemplate('student_display_participated.php');
		$template->set_attribute('evaluations', $evaluations['running']['participated']);
		echo $template->render();
	}

	/**
	 * Zeigt die Hauptseite der abgelaufenen Evaluationen an.
	 * @uses ibit_Evaluation::getEvaluationDataByUserId()
	 */
	function expired_index()
	{
		$evaluations = ibit_Evaluation::getEvaluationDataByUserId( $this->user_id );

		$template = $this->parent->getTemplate('student_display_expired.php');
		$template->set_attribute('evaluations', $evaluations['expired']);
		$template->set_attribute('link_summary', $this->section_link.'&function=summary');
		echo $template->render();
	}

	/**
	 * Zeigt die Auswertung einer Evaluation an.
	 * @uses ibit_Action_Summary
	 */
	function expired_summary()
	{
		$evaluation_id = trim($_REQUEST['evaluation_id']);
		$evaluation = new ibit_Evaluation($evaluation_id);
		if(!$evaluation->isVisible())
		{
			echo Messagebox::error("Diese Evaluation ist nicht fr Studenten freigeschaltet");
			return;
		}
		$summary = new ibit_Action_Summary( $this->parent, $evaluation_id);
		$summary->show();
	}

	function search_index()
	{
		$search = new ibit_Action_EvaluationSearch( $this->parent, $this->section_link);
		$search->show();
	}

	function search_summary()
	{
		$evaluation_id = trim($_REQUEST['evaluation_id']);
		$evaluation = new ibit_Evaluation($evaluation_id);
		if(!$evaluation->isVisible())
		{
			echo Messagebox::error("Diese Evaluation ist nicht fr Studenten freigeschaltet");
			return;
		}
		$summary = new ibit_Action_Summary( $this->parent, $evaluation_id);
		$summary->show();
	}
}
?>